summaryrefslogtreecommitdiffstats
path: root/krita/core/kis_paintop_registry.h
diff options
context:
space:
mode:
Diffstat (limited to 'krita/core/kis_paintop_registry.h')
-rw-r--r--krita/core/kis_paintop_registry.h17
1 files changed, 9 insertions, 8 deletions
diff --git a/krita/core/kis_paintop_registry.h b/krita/core/kis_paintop_registry.h
index c544a601..c61105b6 100644
--- a/krita/core/kis_paintop_registry.h
+++ b/krita/core/kis_paintop_registry.h
@@ -19,14 +19,14 @@
#ifndef KIS_PAINTOP_REGISTRY_H_
#define KIS_PAINTOP_REGISTRY_H_
-#include <qobject.h>
+#include <tqobject.h>
#include "kis_types.h"
#include "kis_generic_registry.h"
#include <koffice_export.h>
-class QWidget;
-class QStringList;
+class TQWidget;
+class TQStringList;
class KisPaintOp;
class KisPaintOpSettings;
@@ -34,10 +34,11 @@ class KisPainter;
class KisColorSpace;
class KisInputDevice;
-class KRITACORE_EXPORT KisPaintOpRegistry : public QObject, public KisGenericRegistry<KisPaintOpFactorySP>
+class KRITACORE_EXPORT KisPaintOpRegistry : public TQObject, public KisGenericRegistry<KisPaintOpFactorySP>
{
Q_OBJECT
+ TQ_OBJECT
public:
virtual ~KisPaintOpRegistry();
@@ -50,21 +51,21 @@ public:
/**
* Return a newly created paintopd
*/
- KisPaintOp * paintOp(const QString& id, const KisPaintOpSettings * settings, KisPainter * painter) const;
+ KisPaintOp * paintOp(const TQString& id, const KisPaintOpSettings * settings, KisPainter * painter) const;
/**
* Create and return an (abstracted) configuration widget
* for using the specified paintop with the specified input device,
* with the specified parent as widget parent. Returns 0 if there
* are no settings available for the given device.
*/
- KisPaintOpSettings * settings(const KisID& id, QWidget * parent, const KisInputDevice& inputDevice) const;
+ KisPaintOpSettings * settings(const KisID& id, TQWidget * tqparent, const KisInputDevice& inputDevice) const;
// Whether we should show this paintop in the toolchest
bool userVisible(const KisID & id, KisColorSpace* cs) const;
// Get the name of the icon to show in the toolchest
- QString pixmap(const KisID & id) const;
+ TQString pixmap(const KisID & id) const;
public:
@@ -50,21 +51,21 @@ public:
* Create and return an (abstracted) configuration widget
* for using the specified paintop with the specified input device,
- * with the specified parent as widget parent. Returns 0 if there
+ * with the specified tqparent as widget tqparent. Returns 0 if there
* are no settings available for the given device.
*/